package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TSettingMapper;
import com.ruoyi.system.domain.TSetting;
import com.ruoyi.system.service.ITSettingService;

/**
 * 手环系统设置Service业务层处理
 * 
 * @author zhengjie
 * @date 2023-09-22
 */
@Service
public class TSettingServiceImpl implements ITSettingService 
{
    @Autowired
    private TSettingMapper tSettingMapper;

    /**
     * 查询手环系统设置
     * 
     * @param id 手环系统设置主键
     * @return 手环系统设置
     */
    @Override
    public TSetting selectTSettingById(Integer id)
    {
        return tSettingMapper.selectTSettingById(id);
    }

    /**
     * 查询手环系统设置列表
     * 
     * @param tSetting 手环系统设置
     * @return 手环系统设置
     */
    @Override
    public List<TSetting> selectTSettingList(TSetting tSetting)
    {
        return tSettingMapper.selectTSettingList(tSetting);
    }

    /**
     * 新增手环系统设置
     * 
     * @param tSetting 手环系统设置
     * @return 结果
     */
    @Override
    public int insertTSetting(TSetting tSetting)
    {
        return tSettingMapper.insertTSetting(tSetting);
    }

    /**
     * 修改手环系统设置
     * 
     * @param tSetting 手环系统设置
     * @return 结果
     */
    @Override
    public int updateTSetting(TSetting tSetting)
    {
        return tSettingMapper.updateTSetting(tSetting);
    }

    /**
     * 批量删除手环系统设置
     * 
     * @param ids 需要删除的手环系统设置主键
     * @return 结果
     */
    @Override
    public int deleteTSettingByIds(Integer[] ids)
    {
        return tSettingMapper.deleteTSettingByIds(ids);
    }

    /**
     * 删除手环系统设置信息
     * 
     * @param id 手环系统设置主键
     * @return 结果
     */
    @Override
    public int deleteTSettingById(Integer id)
    {
        return tSettingMapper.deleteTSettingById(id);
    }
}
